==> openjdk-11_11.0.29+7.orig.tar.xz: openjdk-11-11.0.29+7/test/jdk/java/beans/XMLEncoder/java_awt_MenuShortcut.java <==
/*
 * Copyright (c) 2007, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4818598
 * @summary Tests MenuShortcut value encoding
 * @author Sergey Malenkov
 */

import java.awt.MenuShortcut;
import java.awt.event.KeyEvent;

public final class java_awt_MenuShortcut extends AbstractTest<MenuShortcut> {
    public static void main(String[] args) {
        new java_awt_MenuShortcut().test(true);
    }

    protected MenuShortcut getObject() {
        return new MenuShortcut(KeyEvent.VK_A);
    }

    protected MenuShortcut getAnotherObject() {
        return new MenuShortcut(KeyEvent.VK_Z, true);
    }
}

==> openjdk-25_25+36.orig.tar.xz: openjdk-25-25+36/test/jdk/java/beans/XMLEncoder/java_awt_MenuShortcut.java <==
/*
 * Copyright (c) 2007, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4818598
 * @summary Tests MenuShortcut value encoding
 * @run main/othervm java_awt_MenuShortcut
 * @author Sergey Malenkov
 */

import java.awt.MenuShortcut;
import java.awt.event.KeyEvent;

public final class java_awt_MenuShortcut extends AbstractTest<MenuShortcut> {
    public static void main(String[] args) {
        new java_awt_MenuShortcut().test();
    }

    protected MenuShortcut getObject() {
        return new MenuShortcut(KeyEvent.VK_A);
    }

    protected MenuShortcut getAnotherObject() {
        return new MenuShortcut(KeyEvent.VK_Z, true);
    }
}
